[][src]Crate fprint_sys

Structs

__sigset_t
fd_set
fp_dev
fp_driver
fp_dscv_dev
fp_dscv_print
fp_img
fp_minutia

\ingroup img

fp_pollfd
fp_print_data
itimerval
timespec
timeval
timezone

Constants

FD_SETSIZE
INT8_MIN
INT8_MAX
INT16_MIN
INT16_MAX
INT32_MIN
INT32_MAX
INTPTR_MAX
INTPTR_MIN
INT_FAST8_MIN
INT_FAST8_MAX
INT_FAST16_MIN
INT_FAST16_MAX
INT_FAST32_MIN
INT_FAST32_MAX
INT_LEAST8_MIN
INT_LEAST8_MAX
INT_LEAST16_MIN
INT_LEAST16_MAX
INT_LEAST32_MIN
INT_LEAST32_MAX
PTRDIFF_MAX
PTRDIFF_MIN
SIG_ATOMIC_MAX
SIG_ATOMIC_MIN
SIZE_MAX
UINT8_MAX
UINT16_MAX
UINT32_MAX
UINTPTR_MAX
UINT_FAST8_MAX
UINT_FAST16_MAX
UINT_FAST32_MAX
UINT_LEAST8_MAX
UINT_LEAST16_MAX
UINT_LEAST32_MAX
WINT_MAX
WINT_MIN
_ATFILE_SOURCE
_BITS_STDINT_INTN_H
_BITS_STDINT_UINTN_H
_BITS_TYPESIZES_H
_BITS_TYPES_H
_BITS_WCHAR_H
_DEFAULT_SOURCE
_FEATURES_H
_POSIX_C_SOURCE
_POSIX_SOURCE
_STDC_PREDEF_H
_STDINT_H
_SYS_CDEFS_H
_SYS_SELECT_H
_SYS_TIME_H
__FD_SETSIZE
__FD_ZERO_STOS
__GLIBC_MINOR__
__GLIBC_USE_DEPRECATED_GETS
__GLIBC_USE_IEC_60559_BFP_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT
__GLIBC_USE_IEC_60559_TYPES_EXT
__GLIBC_USE_LIB_EXT2
__GLIBC__
__GNU_LIBRARY__
__HAVE_GENERIC_SELECTION
__INO_T_MATCHES_INO64_T
__OFF_T_MATCHES_OFF64_T
__RLIM_T_MATCHES_RLIM64_T
__STDC_IEC_559__
__STDC_IEC_559_COMPLEX__
__STDC_ISO_10646__
__STDC_NO_THREADS__
__SYSCALL_WORDSIZE
__USE_ATFILE
__USE_FORTIFY_LEVEL
__USE_ISOC11
__USE_ISOC95
__USE_ISOC99
__USE_MISC
__USE_POSIX
__USE_POSIX2
__USE_POSIX199309
__USE_POSIX199506
__USE_POSIX_IMPLICITLY
__USE_XOPEN2K
__USE_XOPEN2K8
__WORDSIZE
__WORDSIZE_TIME64_COMPAT32
__glibc_c99_flexarr_available
__itimer_which_ITIMER_PROF
__itimer_which_ITIMER_REAL
__itimer_which_ITIMER_VIRTUAL
__sigset_t_defined
__time_t_defined
__timespec_defined
__timeval_defined
fp_capture_result_FP_CAPTURE_COMPLETE

Capture completed successfully, the capture data has been returned to the caller.

fp_capture_result_FP_CAPTURE_FAIL

Capture failed for some reason

fp_enroll_result_FP_ENROLL_COMPLETE

Enrollment completed successfully, the enrollment data has been returned to the caller.

fp_enroll_result_FP_ENROLL_FAIL

Enrollment failed due to incomprehensible data; this may occur when the user scans a different finger on each enroll stage.

fp_enroll_result_FP_ENROLL_PASS

Enroll stage passed; more stages are need to complete the process.

fp_enroll_result_FP_ENROLL_RETRY

The enrollment scan did not succeed due to poor scan quality or other general user scanning problem.

fp_enroll_result_FP_ENROLL_RETRY_CENTER_FINGER

The enrollment scan did not succeed because the finger was not centered on the scanner.

fp_enroll_result_FP_ENROLL_RETRY_REMOVE_FINGER

The verification scan did not succeed due to quality or pressure problems; the user should remove their finger from the scanner before retrying.

fp_enroll_result_FP_ENROLL_RETRY_TOO_SHORT

The enrollment scan did not succeed because the finger swipe was too short.

fp_finger_LEFT_INDEX

thumb (left hand)

fp_finger_LEFT_LITTLE

ring finger (left hand)

fp_finger_LEFT_MIDDLE

index finger (left hand)

fp_finger_LEFT_RING

middle finger (left hand)

fp_finger_LEFT_THUMB
fp_finger_RIGHT_INDEX

thumb (right hand)

fp_finger_RIGHT_LITTLE

ring finger (right hand)

fp_finger_RIGHT_MIDDLE

index finger (right hand)

fp_finger_RIGHT_RING

middle finger (right hand)

fp_finger_RIGHT_THUMB

little finger (left hand)

fp_scan_type_FP_SCAN_TYPE_PRESS
fp_scan_type_FP_SCAN_TYPE_SWIPE

press

fp_verify_result_FP_VERIFY_MATCH

The scan completed successfully and the newly scanned fingerprint does match the fingerprint being verified, or in the case of identification, the scanned fingerprint was found in the print gallery.

fp_verify_result_FP_VERIFY_NO_MATCH

The scan completed successfully, but the newly scanned fingerprint does not match the fingerprint being verified against. In the case of identification, this return code indicates that the scanned finger could not be found in the print gallery.

fp_verify_result_FP_VERIFY_RETRY

The scan did not succeed due to poor scan quality or other general user scanning problem.

fp_verify_result_FP_VERIFY_RETRY_CENTER_FINGER

The scan did not succeed because the finger was not centered on the scanner.

fp_verify_result_FP_VERIFY_RETRY_REMOVE_FINGER

The scan did not succeed due to quality or pressure problems; the user should remove their finger from the scanner before retrying.

fp_verify_result_FP_VERIFY_RETRY_TOO_SHORT

The scan did not succeed because the finger swipe was too short.

Functions

adjtime
fp_async_capture_start
fp_async_capture_stop
fp_async_dev_close
fp_async_dev_open
fp_async_enroll_start
fp_async_enroll_stop
fp_async_identify_start
fp_async_identify_stop
fp_async_verify_start
fp_async_verify_stop
fp_dev_close
fp_dev_get_devtype
fp_dev_get_driver
fp_dev_get_img_height
fp_dev_get_img_width
fp_dev_get_nr_enroll_stages
fp_dev_img_capture
fp_dev_open
fp_dev_supports_dscv_print
fp_dev_supports_identification
fp_dev_supports_imaging
fp_dev_supports_print_data
fp_discover_devs
fp_discover_prints
fp_driver_get_driver_id
fp_driver_get_full_name
fp_driver_get_name
fp_driver_get_scan_type
fp_dscv_dev_for_dscv_print
fp_dscv_dev_for_print_data
fp_dscv_dev_get_devtype
fp_dscv_dev_get_driver
fp_dscv_dev_supports_dscv_print
fp_dscv_dev_supports_print_data
fp_dscv_devs_free
fp_dscv_print_delete
fp_dscv_print_get_devtype
fp_dscv_print_get_driver_id
fp_dscv_print_get_finger
fp_dscv_prints_free
fp_enroll_finger_img
fp_exit
fp_get_next_timeout
fp_get_pollfds
fp_handle_events
fp_handle_events_timeout
fp_identify_finger_img
fp_img_binarize
fp_img_free
fp_img_get_data
fp_img_get_height
fp_img_get_minutiae
fp_img_get_width
fp_img_save_to_file
fp_img_standardize
fp_init
fp_print_data_delete
fp_print_data_free
fp_print_data_from_data
fp_print_data_from_dscv_print
fp_print_data_get_data
fp_print_data_get_devtype
fp_print_data_get_driver_id
fp_print_data_load
fp_print_data_save
fp_set_debug
fp_set_pollfd_notifiers
fp_verify_finger_img
futimes
getitimer
gettimeofday
lutimes
pselect
select
setitimer
settimeofday
utimes

Type Definitions

__blkcnt64_t
__blkcnt_t
__blksize_t
__caddr_t
__clock_t
__clockid_t
__daddr_t
__dev_t
__fd_mask
__fsblkcnt64_t
__fsblkcnt_t
__fsfilcnt64_t
__fsfilcnt_t
__fsword_t
__gid_t
__id_t
__ino64_t
__ino_t
__int8_t
__int16_t
__int32_t
__int64_t
__intmax_t
__intptr_t
__itimer_which
__itimer_which_t
__key_t
__loff_t
__mode_t
__nlink_t
__off64_t
__off_t
__pid_t
__quad_t
__rlim64_t
__rlim_t
__sig_atomic_t
__socklen_t
__ssize_t
__suseconds_t
__syscall_slong_t
__syscall_ulong_t
__time_t
__timer_t
__timezone_ptr_t
__u_char
__u_int
__u_long
__u_quad_t
__u_short
__uid_t
__uint8_t
__uint16_t
__uint32_t
__uint64_t
__uintmax_t
__useconds_t
fd_mask
fp_capture_cb
fp_capture_result

\ingroup dev Image capture result codes returned from fp_dev_img_capture().

fp_capture_stop_cb
fp_dev_close_cb
fp_dev_open_cb
fp_enroll_result

\ingroup dev Enrollment result codes returned from fp_enroll_finger(). Result codes with RETRY in the name suggest that the scan failed due to user error. Applications will generally want to inform the user of the problem and then retry the enrollment stage. For more info on the semantics of interpreting these result codes and tracking enrollment process, see \ref enrolling.

fp_enroll_stage_cb
fp_enroll_stop_cb
fp_finger

\ingroup print_data Numeric codes used to refer to fingers (and thumbs) of a human. These are purposely not available as strings, to avoid getting the library tangled up in localization efforts.

fp_identify_cb
fp_identify_stop_cb
fp_pollfd_added_cb
fp_pollfd_removed_cb
fp_scan_type

\ingroup dev Numeric codes used to refer to the scan type of the device. Devices require either swiping or pressing the finger on the device. This is useful for front-ends.

fp_verify_cb
fp_verify_result

\ingroup dev Verification result codes returned from fp_verify_finger(). Return codes are also shared with fp_identify_finger(). Result codes with RETRY in the name suggest that the scan failed due to user error. Applications will generally want to inform the user of the problem and then retry the verify operation.

fp_verify_stop_cb
int_fast8_t
int_fast16_t
int_fast32_t
int_fast64_t
int_least8_t
int_least16_t
int_least32_t
int_least64_t
intmax_t
sigset_t
suseconds_t
time_t
uint_fast8_t
uint_fast16_t
uint_fast32_t
uint_fast64_t
uint_least8_t
uint_least16_t
uint_least32_t
uint_least64_t
uintmax_t
wchar_t