[][src]Type Definition fprint_sys::fp_enroll_result

type fp_enroll_result = u32;

\ingroup dev Enrollment result codes returned from fp_enroll_finger(). Result codes with RETRY in the name suggest that the scan failed due to user error. Applications will generally want to inform the user of the problem and then retry the enrollment stage. For more info on the semantics of interpreting these result codes and tracking enrollment process, see \ref enrolling.