[][src]Type Definition fprint_sys::fp_finger

type fp_finger = u32;

\ingroup print_data Numeric codes used to refer to fingers (and thumbs) of a human. These are purposely not available as strings, to avoid getting the library tangled up in localization efforts.