[][src]Type Definition fprint_sys::fp_verify_result

type fp_verify_result = u32;

\ingroup dev Verification result codes returned from fp_verify_finger(). Return codes are also shared with fp_identify_finger(). Result codes with RETRY in the name suggest that the scan failed due to user error. Applications will generally want to inform the user of the problem and then retry the verify operation.