[−][src]Crate fprint_sys
Structs
| __sigset_t | |
| fd_set | |
| fp_dev | |
| fp_driver | |
| fp_dscv_dev | |
| fp_dscv_print | |
| fp_img | |
| fp_minutia | \ingroup img |
| fp_pollfd | |
| fp_print_data | |
| itimerval | |
| timespec | |
| timeval | |
| timezone |
Constants
Functions
Type Definitions
| __blkcnt64_t | |
| __blkcnt_t | |
| __blksize_t | |
| __caddr_t | |
| __clock_t | |
| __clockid_t | |
| __daddr_t | |
| __dev_t | |
| __fd_mask | |
| __fsblkcnt64_t | |
| __fsblkcnt_t | |
| __fsfilcnt64_t | |
| __fsfilcnt_t | |
| __fsword_t | |
| __gid_t | |
| __id_t | |
| __ino64_t | |
| __ino_t | |
| __int8_t | |
| __int16_t | |
| __int32_t | |
| __int64_t | |
| __intmax_t | |
| __intptr_t | |
| __itimer_which | |
| __itimer_which_t | |
| __key_t | |
| __loff_t | |
| __mode_t | |
| __nlink_t | |
| __off64_t | |
| __off_t | |
| __pid_t | |
| __quad_t | |
| __rlim64_t | |
| __rlim_t | |
| __sig_atomic_t | |
| __socklen_t | |
| __ssize_t | |
| __suseconds_t | |
| __syscall_slong_t | |
| __syscall_ulong_t | |
| __time_t | |
| __timer_t | |
| __timezone_ptr_t | |
| __u_char | |
| __u_int | |
| __u_long | |
| __u_quad_t | |
| __u_short | |
| __uid_t | |
| __uint8_t | |
| __uint16_t | |
| __uint32_t | |
| __uint64_t | |
| __uintmax_t | |
| __useconds_t | |
| fd_mask | |
| fp_capture_cb | |
| fp_capture_result | \ingroup dev Image capture result codes returned from fp_dev_img_capture(). |
| fp_capture_stop_cb | |
| fp_dev_close_cb | |
| fp_dev_open_cb | |
| fp_enroll_result | \ingroup dev Enrollment result codes returned from fp_enroll_finger(). Result codes with RETRY in the name suggest that the scan failed due to user error. Applications will generally want to inform the user of the problem and then retry the enrollment stage. For more info on the semantics of interpreting these result codes and tracking enrollment process, see \ref enrolling. |
| fp_enroll_stage_cb | |
| fp_enroll_stop_cb | |
| fp_finger | \ingroup print_data Numeric codes used to refer to fingers (and thumbs) of a human. These are purposely not available as strings, to avoid getting the library tangled up in localization efforts. |
| fp_identify_cb | |
| fp_identify_stop_cb | |
| fp_pollfd_added_cb | |
| fp_pollfd_removed_cb | |
| fp_scan_type | \ingroup dev Numeric codes used to refer to the scan type of the device. Devices require either swiping or pressing the finger on the device. This is useful for front-ends. |
| fp_verify_cb | |
| fp_verify_result | \ingroup dev Verification result codes returned from fp_verify_finger(). Return codes are also shared with fp_identify_finger(). Result codes with RETRY in the name suggest that the scan failed due to user error. Applications will generally want to inform the user of the problem and then retry the verify operation. |
| fp_verify_stop_cb | |
| int_fast8_t | |
| int_fast16_t | |
| int_fast32_t | |
| int_fast64_t | |
| int_least8_t | |
| int_least16_t | |
| int_least32_t | |
| int_least64_t | |
| intmax_t | |
| sigset_t | |
| suseconds_t | |
| time_t | |
| uint_fast8_t | |
| uint_fast16_t | |
| uint_fast32_t | |
| uint_fast64_t | |
| uint_least8_t | |
| uint_least16_t | |
| uint_least32_t | |
| uint_least64_t | |
| uintmax_t | |
| wchar_t |